/* 
 * Copyright (C) 2006 Piotr Pokora <piotrek.pokora@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MIDGARD_OBJECT_PARAMETER_H
#define MIDGARD_OBJECT_PARAMETER_H

G_BEGIN_DECLS

/**
 * \defgroup object_parameter Midgard Object Parameter
 *
 * Object's parameters is a special Midgard feature which allows 
 * to extend object's data by storing object's parameters identified by 
 * domain, name and value via midgard_parameter type.
 *
 * The main purpose of parameters is to assign some values to object 
 * without any need to set these values as typical object's properties.
 */ 


/**
 * \ingroup object_parameter
 *
 * Get object's parameter
 *
 * \param self, MgdObject instance
 * \param[in] domain, parameter's domain string
 * \param[in] name, parameter's name string
 *
 * \return GValue which holds value for domain&name pair.
 *
 * NULL is returned if parameter record with given domain and name is not found.
 * Returned GValue is owned by midgard-core and shouldn't be freed.
 *
 */ 
extern const GValue *midgard_object_get_parameter(MgdObject *self,
			const gchar *domain, const gchar *name);

/**
 * \ingroup object_parameter
 *
 * Set object's parameter.
 *
 * \param self, MgdObject instance
 * \param[in] domain, parameter's domain string
 * \param[in] name, paramater's name string
 * \param[in] value, a GValue value which should be set for domain&name pair
 * \param[in] lang, boolean which determines if default language should be forced 
 *
 * \return TRUE on success, FALSE otherwise
 *
 * Success means that parameter object is created if it doesn't exist, or is updated
 * otherwise.
 *
 */ 
extern gboolean midgard_object_set_parameter(MgdObject *self,
			const gchar *domain, const gchar *name,
			GValue *value, gboolean lang);

G_END_DECLS

#endif /* MIDGARD_OBJECT_PARAMETER_H */
