/* 
 * Copyright (C) 2006 Piotr Pokora <piotr.pokora@infoglob.pl>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MIDGARD_REQUEST_H
#define MIDGARD_REQUEST_H

#include <glib-object.h>

G_BEGIN_DECLS

/* convention macros */
#define MIDGARD_TYPE_REQUEST (midgard_request_get_type())
#define MIDGARD_REQUEST(object)  \
	        (G_TYPE_CHECK_INSTANCE_CAST ((object),MIDGARD_TYPE_REQUEST, MidgardRequest))
#define MIDGARD_REQUEST_CLASS(klass)  \
	        (G_TYPE_CHECK_CLASS_CAST ((klass), MIDGARD_TYPE_REQUEST, MidgardRequestClass))
#define MIDGARD_IS_REQUEST(object)   \
	        (G_TYPE_CHECK_INSTANCE_TYPE ((object), MIDGARD_TYPE_REQUEST))
#define MIDGARD_IS_REQUEST_CLASS(klass) \
	        (G_TYPE_CHECK_CLASS_TYPE ((klass), MIDGARD_TYPE_REQUEST))
#define MIDGARD_REQUEST_GET_CLASS(obj) \
	        (G_TYPE_INSTANCE_GET_CLASS ((obj), MIDGARD_TYPE_REQUEST, MidgardRequestClass))

typedef struct MidgardRequest MidgardRequest;
typedef struct MidgardRequestClass MidgardRequestClass;
typedef struct _MidgardRequestPrivate MidgardRequestPrivate; 

/**
 * 
 * \defgroup midgard_request Midgard Request
 *  
 * The MidgardRequestClass class structure . 
 */
struct MidgardRequestClass{
	
	GObjectClass parent;
};

/**
 *
 * \ingroup midgard_request
 *
 * The MidgardRequest object structure.
 */ 
struct MidgardRequest{

	GObject parent;

	/* < public > */
	GObject *host;
	GObject *page;
	GValueArray *pages;
	gchar *style;
	gchar *prefix;
	gchar *uri;
	gchar *self;
	gboolean auth_required;
	gboolean is_auth;
	GValueArray *argv;
	guint argc;
	
	/* < private > */
	MidgardRequestPrivate *private;
};

/**
 *
 * \ingroup midgard_request
 *
 * Returns the MidgardRequest value type. 
 * Registers the type as  a fundamental GType unless already registered.
 *
 */
extern GType midgard_request_get_type(void);

/**
 *
 * \ingroup midgard_request 
 * 
 * Creates new MidgardRequest object instance.
 *
 * \return pointer to MidgardRequest object or NULL on failure.
 * 
 */ 
extern MidgardRequest *midgard_request_new(void);

G_END_DECLS

#endif /* MIDGARD_CONNNECTION_H */
